@@ -196,6 +196,47 @@ define_crit1_cutoff(data_sessions = sgdata,
 #              identify_sg_1to2 = FALSE,
 #              crit123_details = TRUE)
 
+## ------------------------------------------------------------------------
+# Check interval for sudden gain using all 3 criteria
+# No missing data, alpha = 0.05
+check_interval(pre_values = c(32, 31, 33),
+               post_values = c(5, 6, 7),
+               sg_crit1_cutoff = 7,
+               sg_crit2_pct = .25,
+               sg_crit3 = TRUE,
+               sg_crit3_alpha = .05,
+               identify = "sg")
+
+# Check interval for sudden gain using all 3 criteria
+# No missing data, alpha = 0.01
+check_interval(pre_values = c(32, 31, 33),
+               post_values = c(5, 6, 7),
+               sg_crit1_cutoff = 7,
+               sg_crit2_pct = .25,
+               sg_crit3 = TRUE,
+               sg_crit3_alpha = .01,
+               identify = "sg")
+
+# Check intervall for sudden gain using only third criterion
+# Some missing data, alpha = 0.01
+check_interval(pre_values = c(NA, 31, 33),
+               post_values = c(5, NA, 7),
+               sg_crit1_cutoff = NULL,
+               sg_crit2_pct = NULL,
+               sg_crit3 = TRUE,
+               sg_crit3_alpha = .01,
+               identify = "sg")
+
+# Check intervall for sudden loss using all three criteria
+# Some missing data, alpha = 0.05
+check_interval(pre_values = c(5, NA, 7),
+               post_values = c(16, 12, 14),
+               sg_crit1_cutoff = -7,
+               sg_crit2_pct = .25,
+               sg_crit3 = TRUE,
+               sg_crit3_alpha = .05,
+               identify = "sl")
+
 ## ------------------------------------------------------------------------
 bysg <- create_bysg(data = sgdata,
                     sg_crit1_cutoff = 7,
